@@ -1,9 +1,9 @@
 context("Alias")
-roc <- rd_roclet()
 
 test_that("aliases split into pieces", {
-  out <- roc_proc_text(roc, "
+  out <- roc_proc_text(rd_roclet(), "
     #' @aliases a b
+    #'
     #' @name a
     NULL")[[1]]
 
@@ -12,11 +12,11 @@ test_that("aliases split into pieces", {
 })
 
 test_that("aliases escaped, not quoted", {
-  out1 <- roc_proc_text(roc, "
+  out1 <- roc_proc_text(rd_roclet(), "
     #' @aliases a
     #' @name %a%
     NULL")[[1]]
-  out2 <- roc_proc_text(roc, "
+  out2 <- roc_proc_text(rd_roclet(), "
     #' @aliases %a%
     #' @name a
     NULL")[[1]]
@@ -27,7 +27,7 @@ test_that("aliases escaped, not quoted", {
 })
 
 test_that("can use NULL to suppress default aliases", {
-  out <- roc_proc_text(roc, "
+  out <- roc_proc_text(rd_roclet(), "
     #' @aliases NULL
     #' @name a
     NULL")[[1]]
@@ -37,20 +37,20 @@ test_that("can use NULL to suppress default aliases", {
 
 
 test_that("refclass with assignment gets both aliases", {
-  out <- roc_proc_text(roc, "
+  out <- roc_proc_text(rd_roclet(), "
     #' Title
-    B <- setRefClass('B')
+    B3 <- setRefClass('B3')
   ")[[1]]
 
-  expect_equal(get_tag(out, "alias")$value, c("B-class", "B"))
+  expect_equal(get_tag(out, "alias")$value, c("B3-class", "B3"))
 })
 
 
 test_that("refclass gets -class alias", {
-  out <- roc_proc_text(roc, "
+  out <- roc_proc_text(rd_roclet(), "
     #' Title
-    setRefClass('B')
+    setRefClass('B2')
   ")[[1]]
 
-  expect_equal(get_tag(out, "alias")$value, "B-class")
+  expect_equal(get_tag(out, "alias")$value, "B2-class")
 })
