@@ -3,21 +3,23 @@ test_that("long families are wrapped", {
   out <- roc_proc_text(rd_roclet(), "
     #' Title
     #' @family Long family name
+    #'
     long_function_name_________________________1 <- function() {}
 
     #' Title
     #' @family Long family name
     long_function_name_________________________2 <- function() {}
-    
+
     #' Title
     #' @family Long family name
+    #'
     long_function_name_________________________3 <- function() {}
-    
+
     #' Title
     #' @family Long family name
-    long_function_name_________________________4 <- function() {}  
+    long_function_name_________________________4 <- function() {}
   ")[[1]]
-  
+
   seealso <- get_tag(out, "seealso")$values
   expect_equal(str_count(seealso, "\n"), 2)
 
@@ -33,8 +35,28 @@ test_that("special names escaped in family tag", {
     #' @family Long family name
     '%+%' <- function(a, b) {}
   ")[[1]]
-  
+
   seealso <- get_tag(out, "seealso")$values
   expect_match(seealso, "\\\\%\\+\\\\%")
-  
-})
\ No newline at end of file
+
+})
+
+test_that("family links to name only, not all aliases", {
+  out <- roc_proc_text(rd_roclet(), "
+    #' Title
+    #' @aliases f2 f3
+    #'
+    #' @family many aliases
+    f <- function() {}
+
+    #' Title
+    #' @aliases g2 g3
+    #'
+    #' @family many aliases
+    g <- function() {}
+  ")[[1]]
+
+  seealso <- get_tag(out, "seealso")$values
+  expect_equal(str_count(seealso, fixed("\\code{\\link")), 1)
+
+})
